Exception: Acl9::AccessDenied
- Inherits:
-
RuntimeError
- Object
- RuntimeError
- RuntimeError
- Acl9::AccessDenied
- Defined in:
- lib/acl9.rb
Overview
This exception is raised whenever ACL block finds that the current user is not authorized for the controller action he wants to execute.